@@ -9,6 +9,8 @@ __all__ = [
     'CardActivation',
     'CardTransaction',
     'CardValidation',
+    'CashReference',
+    'Clabe',
     'CurpValidation',
     'Commission',
     'Deposit',
@@ -17,7 +19,11 @@ __all__ = [
     'FileBatch',
     'Identity',
     'IdentityEvent',
+    'KYCValidation',
+    'KYCVerification',
+    'LimitedWallet',
     'LoginToken',
+    'Platform',
     'Saving',
     'ServiceProvider',
     'Session',
@@ -27,6 +33,7 @@ __all__ = [
     'UserCredential',
     'UserEvent',
     'UserLogin',
+    'Verification',
     'WalletTransaction',
     'Webhook',
     'WhatsappTransfer',
@@ -47,6 +54,8 @@ from .resources import (
     CardActivation,
     CardTransaction,
     CardValidation,
+    CashReference,
+    Clabe,
     Commission,
     CurpValidation,
     Deposit,
@@ -55,7 +64,11 @@ from .resources import (
     FileBatch,
     Identity,
     IdentityEvent,
+    KYCValidation,
+    KYCVerification,
+    LimitedWallet,
     LoginToken,
+    Platform,
     Saving,
     ServiceProvider,
     Session,
@@ -65,6 +78,7 @@ from .resources import (
     UserCredential,
     UserEvent,
     UserLogin,
+    Verification,
     WalletTransaction,
     Webhook,
     WhatsappTransfer,
